@@ -14,31 +14,30 @@
 # ==============================================================================
 """Library for computing privacy values for DP-SGD."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import math
 
 from absl import app
-
-from tensorflow_privacy.privacy.analysis.rdp_accountant import compute_rdp  # pylint: disable=g-import-not-at-top
-from tensorflow_privacy.privacy.analysis.rdp_accountant import get_privacy_spent
+import dp_accounting
 
 
 def apply_dp_sgd_analysis(q, sigma, steps, orders, delta):
   """Compute and print results of DP-SGD analysis."""
 
-  # compute_rdp requires that sigma be the ratio of the standard deviation of
-  # the Gaussian noise to the l2-sensitivity of the function to which it is
-  # added. Hence, sigma here corresponds to the `noise_multiplier` parameter
-  # in the DP-SGD implementation found in privacy.optimizers.dp_optimizer
-  rdp = compute_rdp(q, sigma, steps, orders)
+  accountant = dp_accounting.rdp.RdpAccountant(orders)
 
-  eps, _, opt_order = get_privacy_spent(orders, rdp, target_delta=delta)
+  event = dp_accounting.SelfComposedDpEvent(
+      dp_accounting.PoissonSampledDpEvent(q,
+                                          dp_accounting.GaussianDpEvent(sigma)),
+      steps)
 
-  print('DP-SGD with sampling rate = {:.3g}% and noise_multiplier = {} iterated'
-        ' over {} steps satisfies'.format(100 * q, sigma, steps), end=' ')
+  accountant.compose(event)
+
+  eps, opt_order = accountant.get_epsilon_and_optimal_order(delta)
+
+  print(
+      'DP-SGD with sampling rate = {:.3g}% and noise_multiplier = {} iterated'
+      ' over {} steps satisfies'.format(100 * q, sigma, steps),
+      end=' ')
   print('differential privacy with eps = {:.3g} and delta = {}.'.format(
       eps, delta))
   print('The optimal RDP order is {}.'.format(opt_order))
