@@ -11,17 +11,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""Tests for GaussianSumQuery."""
-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
 from absl.testing import parameterized
 import numpy as np
-from six.moves import xrange
-import tensorflow.compat.v1 as tf
-
+import tensorflow as tf
 from tensorflow_privacy.privacy.dp_query import gaussian_query
 from tensorflow_privacy.privacy.dp_query import test_utils
 
@@ -56,13 +49,14 @@ class GaussianQueryTest(tf.test.TestCase, parameterized.TestCase):
       record2 = tf.constant([4.0, -3.0])  # Not clipped.
 
       l2_norm_clip = tf.Variable(5.0)
-      l2_norm_clip_placeholder = tf.placeholder(tf.float32)
-      assign_l2_norm_clip = tf.assign(l2_norm_clip, l2_norm_clip_placeholder)
+      l2_norm_clip_placeholder = tf.compat.v1.placeholder(tf.float32)
+      assign_l2_norm_clip = tf.compat.v1.assign(l2_norm_clip,
+                                                l2_norm_clip_placeholder)
       query = gaussian_query.GaussianSumQuery(
           l2_norm_clip=l2_norm_clip, stddev=0.0)
       query_result, _ = test_utils.run_query(query, [record1, record2])
 
-      self.evaluate(tf.global_variables_initializer())
+      self.evaluate(tf.compat.v1.global_variables_initializer())
       result = sess.run(query_result)
       expected = [1.0, 1.0]
       self.assertAllClose(result, expected)
@@ -81,7 +75,7 @@ class GaussianQueryTest(tf.test.TestCase, parameterized.TestCase):
       query_result, _ = test_utils.run_query(query, [record1, record2])
 
       noised_sums = []
-      for _ in xrange(1000):
+      for _ in range(1000):
         noised_sums.append(sess.run(query_result))
 
       result_stddev = np.std(noised_sums)
