@@ -11,18 +11,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""Tests for NestedQuery."""
-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
 import collections
 
 from absl.testing import parameterized
 import numpy as np
-import tensorflow.compat.v1 as tf
-
+import tensorflow as tf
 from tensorflow_privacy.privacy.dp_query import dp_query
 from tensorflow_privacy.privacy.dp_query import gaussian_query
 from tensorflow_privacy.privacy.dp_query import nested_query
@@ -125,7 +119,23 @@ class NestedQueryTest(tf.test.TestCase, parameterized.TestCase):
   def test_raises_with_non_sum(self):
 
     class NonSumDPQuery(dp_query.DPQuery):
-      pass
+
+      def initial_sample_state(self, template=None):
+        del template  # Unused.
+        return None
+
+      def accumulate_preprocessed_record(self, sample_state,
+                                         preprocessed_record):
+        del sample_state, preprocessed_record  # Unused.
+        return None
+
+      def merge_sample_states(self, sample_state_1, sample_state_2):
+        del sample_state_1, sample_state_2  # Unused.
+        return None
+
+      def get_noised_result(self, sample_state, global_state):
+        del sample_state, global_state  # Unused.
+        return None
 
     non_sum_query = NonSumDPQuery()
 
@@ -143,6 +153,23 @@ class NestedQueryTest(tf.test.TestCase, parameterized.TestCase):
       def __init__(self, metric_val):
         self._metric_val = metric_val
 
+      def initial_sample_state(self, template=None):
+        del template  # Unused.
+        return None
+
+      def accumulate_preprocessed_record(self, sample_state,
+                                         preprocessed_record):
+        del sample_state, preprocessed_record  # Unused.
+        return None
+
+      def merge_sample_states(self, sample_state_1, sample_state_2):
+        del sample_state_1, sample_state_2  # Unused.
+        return None
+
+      def get_noised_result(self, sample_state, global_state):
+        del sample_state, global_state  # Unused.
+        return None
+
       def derive_metrics(self, global_state):
         return collections.OrderedDict(metric=self._metric_val)
 
