@@ -13,19 +13,14 @@
 # limitations under the License.
 """Vectorized differentially private optimizers for TensorFlow."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from absl import logging
+import tensorflow as tf
 
-import tensorflow.compat.v1 as tf
-
-AdagradOptimizer = tf.train.AdagradOptimizer
-AdamOptimizer = tf.train.AdamOptimizer
-GradientDescentOptimizer = tf.train.GradientDescentOptimizer
-parent_code = tf.train.Optimizer.compute_gradients.__code__
-GATE_OP = tf.train.Optimizer.GATE_OP  # pylint: disable=invalid-name
+AdagradOptimizer = tf.compat.v1.train.AdagradOptimizer
+AdamOptimizer = tf.compat.v1.train.AdamOptimizer
+GradientDescentOptimizer = tf.compat.v1.train.GradientDescentOptimizer
+parent_code = tf.compat.v1.train.Optimizer.compute_gradients.__code__
+GATE_OP = tf.compat.v1.train.Optimizer.GATE_OP  # pylint: disable=invalid-name
 
 
 def make_vectorized_optimizer_class(cls):
@@ -104,10 +99,11 @@ def make_vectorized_optimizer_class(cls):
         *args: These will be passed on to the base class `__init__` method.
         **kwargs: These will be passed on to the base class `__init__` method.
       """
-      super(DPOptimizerClass, self).__init__(*args, **kwargs)
+      super().__init__(*args, **kwargs)
       self._l2_norm_clip = l2_norm_clip
       self._noise_multiplier = noise_multiplier
       self._num_microbatches = num_microbatches
+      self._was_compute_gradients_called = False
 
     def compute_gradients(self,
                           loss,
@@ -118,6 +114,7 @@ def make_vectorized_optimizer_class(cls):
                           grad_loss=None,
                           gradient_tape=None):
       """DP-SGD version of base class method."""
+      self._was_compute_gradients_called = True
       if callable(loss):
         # TF is running in Eager mode
         raise NotImplementedError('Vectorized optimizer unavailable for TF2.')
@@ -138,19 +135,15 @@ def make_vectorized_optimizer_class(cls):
 
         if var_list is None:
           var_list = (
-              tf.trainable_variables() + tf.get_collection(
-                  tf.GraphKeys.TRAINABLE_RESOURCE_VARIABLES))
+              tf.compat.v1.trainable_variables() + tf.compat.v1.get_collection(
+                  tf.compat.v1.GraphKeys.TRAINABLE_RESOURCE_VARIABLES))
 
         def process_microbatch(microbatch_loss):
           """Compute clipped grads for one microbatch."""
           microbatch_loss = tf.reduce_mean(input_tensor=microbatch_loss)
           grads, _ = zip(*super(DPOptimizerClass, self).compute_gradients(
-              microbatch_loss,
-              var_list,
-              gate_gradients,
-              aggregation_method,
-              colocate_gradients_with_ops,
-              grad_loss))
+              microbatch_loss, var_list, gate_gradients, aggregation_method,
+              colocate_gradients_with_ops, grad_loss))
           grads_list = [
               g if g is not None else tf.zeros_like(v)
               for (g, v) in zip(list(grads), var_list)
@@ -184,6 +177,17 @@ def make_vectorized_optimizer_class(cls):
 
         return list(zip(final_grads, var_list))
 
+    def apply_gradients(self, grads_and_vars, global_step=None, name=None):
+      # pylint: disable=g-doc-args, g-doc-return-or-yield
+      """DP-SGD version of base class method."""
+      assert self._was_compute_gradients_called, (
+          'compute_gradients() on the differentially private optimizer was not'
+          ' called. Which means that the training is not differentially '
+          'private. It happens for example in Keras training in TensorFlow '
+          '2.0+.')
+      return super(DPOptimizerClass, self).apply_gradients(
+          grads_and_vars=grads_and_vars, global_step=global_step, name=name)
+
   return DPOptimizerClass
 
 
